import os
import win32com.client
import winreg

import requests, subprocess, time
from contextlib import contextmanager

from .fun_base import log, create_file_path

default_chrome_user_data = 'D:\chrome_user_data'

def set_chrome_system_path():
    path = os.path.dirname(find_software_install_path('chrome'))
    add_to_system_path(path)

def add_to_system_path(path: str, scope: str = "user"):
    """
    将指定路径添加到系统环境变量 Path 中
    :param path: 要添加的路径（应为绝对路径）
    :param scope: 'user' 表示用户变量，'system' 表示系统变量（需要管理员权限）
    """
    if not os.path.isabs(path):
        raise ValueError("必须提供绝对路径")

    path = os.path.normpath(path)

    if scope == "user":
        root = winreg.HKEY_CURRENT_USER
        subkey = r"Environment"
    elif scope == "system":
        root = winreg.HKEY_LOCAL_MACHINE
        subkey = r"SYSTEM\CurrentControlSet\Control\Session Manager\Environment"
    else:
        raise ValueError("scope 参数必须是 'user' 或 'system'")

    try:
        with winreg.OpenKey(root, subkey, 0, winreg.KEY_READ | winreg.KEY_WRITE) as key:
            current_path, _ = winreg.QueryValueEx(key, "Path")
            paths = current_path.split(";")

            if path in paths:
                print("路径已存在于 Path 中，无需添加: ", path)
                return False

            new_path = current_path + ";" + path
            winreg.SetValueEx(key, "Path", 0, winreg.REG_EXPAND_SZ, new_path)
            print("✅ 路径已成功添加到Path中: ", new_path)
            return True

    except PermissionError:
        print("❌ 权限不足，系统变量修改需要管理员权限")
        return False
    except Exception as e:
        print(f"❌ 添加失败: {e}")
        return False

def find_software_install_path(app_keyword: str):
    """从开始菜单或桌面查找指定软件的安装路径"""
    possible_dirs = [
        os.environ.get('PROGRAMDATA', '') + r'\Microsoft\Windows\Start Menu\Programs',
        os.environ.get('APPDATA', '') + r'\Microsoft\Windows\Start Menu\Programs',
        os.environ.get('USERPROFILE', '') + r'\Desktop',
        os.environ.get('PUBLIC', '') + r'\Desktop'
    ]

    shell = win32com.client.Dispatch("WScript.Shell")

    for base_dir in possible_dirs:
        for root, _, files in os.walk(base_dir):
            for file in files:
                if file.lower().endswith('.lnk') and app_keyword.lower() in file.lower():
                    lnk_path = os.path.join(root, file)
                    try:
                        shortcut = shell.CreateShortcut(lnk_path)
                        target_path = shortcut.Targetpath
                        if os.path.exists(target_path):
                            return target_path
                    except Exception as e:
                        continue

    log(f'未能查找到{str}安装位置')
    return None

def init_chrome_env(account_list):
    target = find_software_install_path('chrome')
    for account in account_list:
        store_key, port, *rest = account
        user_data = rest[0] if rest and rest[0] else fr'{default_chrome_user_data}\{port}'
        create_file_path(user_data)
        args = fr'--remote-debugging-port={port} --user-data-dir="{user_data}"'
        shortcut_name = f'{port}_{store_key}.lnk'
        create_shortcut_on_desktop(target_path=target, arguments=args, shortcut_name=shortcut_name)

def create_shortcut_on_desktop(target_path, arguments='', shortcut_name='MyShortcut.lnk', icon_path=None):
    """
    在桌面上创建快捷方式，若已存在指向相同 target + arguments 的快捷方式，则跳过创建。
    """
    # 获取当前用户桌面路径
    desktop_path = os.path.join(os.environ['USERPROFILE'], 'Desktop')

    shell = win32com.client.Dispatch('WScript.Shell')

    # 检查是否已有相同目标的快捷方式
    for file in os.listdir(desktop_path):
        if file.lower().endswith('.lnk'):
            shortcut_file = os.path.join(desktop_path, file)
            shortcut = shell.CreateShortCut(shortcut_file)
            if (os.path.normpath(shortcut.Targetpath) == os.path.normpath(target_path)
                    and shortcut.Arguments.strip() == arguments.strip()):
                log("已存在指向该 target + args 的快捷方式，跳过创建")
                return

    # 创建新的快捷方式
    shortcut_path = os.path.join(desktop_path, shortcut_name)
    shortcut = shell.CreateShortCut(shortcut_path)
    shortcut.Targetpath = target_path
    shortcut.Arguments = arguments
    shortcut.WorkingDirectory = os.path.dirname(target_path)
    if icon_path:
        shortcut.IconLocation = icon_path
    shortcut.save()
    log(f"已创建快捷方式：{shortcut_path}")

def check_chrome_dev(port=3000):
    try:
        url = f"http://127.0.0.1:{port}/json"
        response = requests.get(url, timeout=5)  # 设置超时，避免长时间等待
        if response.status_code == 200:
            try:
                data = response.json()
                if data:
                    # print("接口返回了数据：", data)
                    print("接口返回了数据：")
                    return True
                else:
                    print("接口返回了空数据")
                    return False
            except ValueError:
                print("返回的不是有效的 JSON")
                return False
        else:
            print(f"接口返回了错误状态码: {response.status_code}")
            return False
    except requests.RequestException as e:
        print(f"请求接口时发生错误: {e}")
        return False

def is_chrome_running():
    try:
        output = subprocess.check_output('tasklist', shell=True, text=True)
        return 'chrome.exe' in output.lower()
    except subprocess.CalledProcessError:
        return False

@contextmanager
def get_chrome_page_v3(p, port=3000, user_data=None):
    browser = context = page = None
    is_custom_chrome_opened = False  # 标记是否是程序自己开的浏览器

    try:
        if not check_chrome_dev(port):
            set_chrome_system_path()
            chrome_path = r'"chrome.exe"'
            debugging_port = fr"--remote-debugging-port={port}"
            if user_data is not None:
                chrome_user_data = fr'--user-data-dir="{user_data}"'
            else:
                chrome_user_data = fr'--user-data-dir="{create_file_path(default_chrome_user_data)}\{port}"'

            disable_webrtc = "--disable-features=WebRTC"
            disable_webrtc_hw_encoder = "--disable-features=WebRTC-HW-ENCODER"
            disable_webrtc_alt = "--disable-webrtc"
            start_maximized = "--start-maximized"

            command = f"{chrome_path} {debugging_port} {chrome_user_data} {disable_webrtc} {disable_webrtc_hw_encoder} {disable_webrtc_alt}"
            subprocess.Popen(command, shell=True)
            is_custom_chrome_opened = True
            time.sleep(1)

        browser = p.chromium.connect_over_cdp(f"http://127.0.0.1:{port}")
        context = browser.contexts[0] if browser.contexts else browser.new_context()
        page = context.pages[0] if context.pages else context.new_page()

        yield browser, context, page

    except Exception as e:
        # 向上抛出错误，否则主函数感知不到错误
        raise

    finally:
        for obj in [("page", page), ("context", context), ("browser", browser)]:
            name, target = obj
            try:
                if target and is_custom_chrome_opened:
                    log(f'关闭: {name}')
                    target.close()
            except Exception:
                pass  # 你可以在这里加日志记录关闭失败



from .fun_excel import *
from .fun_base import log
from .fun_file import read_dict_from_file, read_dict_from_file_ex, write_dict_to_file, write_dict_to_file_ex, delete_file
from .time_utils import TimeUtils
from .wxwork import WxWorkBot
import os

class TemuExcel:

    def __init__(self, config, bridge):
        self.config = config
        self.bridge = bridge

    def write_funds(self):
        cache_file = f'{self.config.auto_dir}/temu/cache/funds_{TimeUtils.today_date()}.json'
        dict = read_dict_from_file(cache_file)
        data = []
        for key, val in dict.items():
            data.append(val)

        excel_path = create_file_path(self.config.excel_temu_fund)
        data.insert(0, ['汇总', '', '', '', ''])
        data.insert(0, ['店铺名称', '总金额', '可用余额', '-', '导出时间'])
        log(data)
        # 删除第 4 列（索引为 3）
        for row in data:
            row.pop(3)  # 删除每行中索引为 3 的元素

        write_data(excel_path, 'Sheet1', data)

        app, wb, sheet = open_excel(excel_path, 'Sheet1')
        beautify_title(sheet)
        format_to_money(sheet, ['金额', '余额'])
        format_to_datetime(sheet, ['时间'])
        add_sum_for_cell(sheet, ['总金额', '可用余额'])
        add_borders(sheet)
        close_excel(app, wb)

    def format_purchase_advise_batch(self, sheet):
        beautify_title(sheet)
        format_to_datetime(sheet, ['时间'])
        format_to_number(sheet, ['平均日销', '本地和采购可售天数', '建议采购'], 1)
        add_borders(sheet)
        add_formula_for_column(sheet, '平均日销', '=G2/7')
        add_formula_for_column(sheet, '本地和采购可售天数', '=IF(H2>0,(E2+F2)/H2,0)')
        add_formula_for_column(sheet, '建议采购', '=IF(J2>I2,H2*9,0)')
        colorize_by_field(sheet, 'SKC')
        autofit_column(sheet, ['店铺名称', '商品信息'])
        column_to_left(sheet, ['商品信息'])
        InsertImageV2(sheet, ['SKC图片', 'SKU图片'], 'temu', 120)
        # if sheet.used_range.rows.count > 330:
        #     log('表格数据行数超过了330行,将删除SKC图片')
        #     remove_excel_columns(sheet, ['SKC图片'])

    def write_purchase_advise(self, erp='mb'):
        cache_file = f'{self.config.auto_dir}/temu/cache/warehouse_list_{TimeUtils.today_date()}.json'
        dict = read_dict_from_file(cache_file)

        store_info = read_dict_from_file(self.config.temu_store_info)

        header = ['店铺名称', 'SKC图片', 'SKU图片', '商品信息', '现有库存数量', '已采购数量', '近7日销量', '平均日销', '本地和采购可售天数', '生产天数', '建议采购', '产品起定量', '备货周期(天)', 'SKC', '导出时间']
        new_excel_path_list = []
        
        for mall_id, subOrderList in dict.items():
            excel_data = []
            mall_name = store_info.get(mall_id)[1]
            
            for product in subOrderList:
                spu = str(product['productId'])  # temu平台 spu_id
                skc = str(product['productSkcId'])  # temu平台 skc_id
                skcExtCode = product['skcExtCode']  # 商家 SKC货号
                category = product['category']  # 叶子类目
                onSalesDurationOffline = product['onSalesDurationOffline']  # 加入站点时长
                
                for sku in product['skuQuantityDetailList']:
                    priceReviewStatus = sku['priceReviewStatus']
                    if priceReviewStatus == 3:  # 过滤 开款价格状态 已作废的  2是已生效
                        continue
                    
                    mall_info = f'{mall_name}\n{mall_id}'
                    productSkcPicture = product['productSkcPicture']  # skc图片
                    skuExtCode = str(sku['skuExtCode'])  # sku货号
                    sku_img = self.bridge.get_sku_img(skuExtCode, erp)
                    stock = self.bridge.get_sku_stock(skuExtCode, erp)

                    product_info = f"SPU: {spu}\nSKC: {skc}\nSKC货号: {skcExtCode}\nSKU货号: {skuExtCode}\n属性集: {sku['className']}\n类目: {category}\n加入站点时长: {onSalesDurationOffline}天\n"

                    row_item = []
                    row_item.append(mall_info)
                    row_item.append(productSkcPicture)
                    row_item.append(sku_img)
                    row_item.append(product_info)
                    row_item.append(stock)
                    row_item.append(0)
                    row_item.append(sku['lastSevenDaysSaleVolume'])
                    row_item.append(0)
                    row_item.append(0)
                    row_item.append(7)
                    row_item.append(0)
                    row_item.append(0)
                    row_item.append(0)
                    row_item.append(skc)
                    row_item.append(TimeUtils.current_datetime())
                    excel_data.append(row_item)

            # 按近7日销量排序
            excel_data = sort_by_column(excel_data, 6, 1)
            
            # 计算需要多少个文件（每个文件最多320行数据，包含表头）
            max_data_rows = 250 - 1  # 减去表头行
            total_files = (len(excel_data) + max_data_rows - 1) // max_data_rows  # 通过加(max_data_rows-1)实现向上取整
            
            for file_index in range(total_files):
                start_idx = file_index * max_data_rows
                end_idx = min((file_index + 1) * max_data_rows, len(excel_data))
                current_data = excel_data[start_idx:end_idx]
                
                # 生成文件名，如果超过一个文件则添加序号
                if total_files == 1:
                    new_excel_path = str(self.config.excel_purcase_advice_temu).replace('#store_name#', mall_name).replace(' ', '_')
                else:
                    # 在文件名后添加 _2, _3 等序号
                    base_path = str(self.config.excel_purcase_advice_temu).replace('#store_name#', mall_name).replace(' ', '_')
                    file_name, file_ext = os.path.splitext(base_path)
                    new_excel_path = f"{file_name}_{file_index + 1}{file_ext}"
                
                new_excel_path_list.append(new_excel_path)
                sheet_name = 'Sheet1'
                data = [header] + current_data
                
                close_excel_file(new_excel_path)
                log(f"创建文件: {new_excel_path}, 数据行数: {len(current_data)}")
                
                batch_excel_operations(new_excel_path, [
                    (sheet_name, 'write', data, ['N']),
                    (sheet_name, 'format', self.format_purchase_advise_batch)
                ])

        return new_excel_path_list



from .fun_base import log

import sqlite3
from datetime import datetime, timedelta
import os
import sys


auto_dir = 'D:/auto'
db_file = f'{auto_dir}/shein/db/shein_sku_sales.db'

# log(db_file)


def main(args):
    init_db()
    # exists_sales_1_days_ago('653231597')
    # log(get_last_week_sales('6960380466'))
    # log(get_sales('6960380466', '2025-02-25', '2025-03-04'))
    # log(get_near_week_sales('I46mraado10r'))
    # log(get_last_week_sales('I46mraado10r','2025-03-08','2025-03-14'))
    # create_indexes()

def init_db():
    # 获取文件夹路径
    folder_path = os.path.dirname(db_file)
    # 如果文件夹不存在，则创建
    if not os.path.exists(folder_path):
        os.makedirs(folder_path)
        log(f"文件夹已创建: {folder_path}")
    conn = sqlite3.connect(db_file)
    cursor = conn.cursor()
    cursor.execute('''
        CREATE TABLE IF NOT EXISTS sales (
            id INTEGER PRIMARY KEY AUTOINCREMENT,
            skc TEXT,
            date TEXT,
            skc_sale INTEGER,
            skc_order INTEGER,
            sku TEXT,
            attr_name TEXT,
            sku_sale INTEGER,
            sku_order INTEGER
        )
    ''')
    conn.commit()
    conn.close()
    log('新建数据库成功', db_file)

init_db()

def insert_sales(skc, date, skc_sale, skc_order, sku, attr_name, sku_sale, sku_order):
    conn = sqlite3.connect(db_file)
    cursor = conn.cursor()
    cursor.execute('''
        SELECT 1 FROM sales WHERE sku = ? AND date = ?
    ''', (sku, date))

    if cursor.fetchone() is None:
        cursor.execute('''
            INSERT INTO sales (skc, date, skc_sale, skc_order, sku, attr_name, sku_sale, sku_order)
            VALUES (?, ?, ?, ?, ?, ?, ?, ?)
        ''', (skc, date, skc_sale, skc_order, sku, attr_name, sku_sale, sku_order))
        conn.commit()

    conn.close()

def get_sales(sku, start_date, end_date):
    conn = sqlite3.connect(db_file)
    cursor = conn.cursor()
    cursor.execute('''
        SELECT SUM(sku_sale), SUM(sku_order) FROM sales WHERE sku = ? AND date BETWEEN ? AND ?
    ''', (sku, start_date, end_date))

    result = cursor.fetchone()  # 获取查询结果
    sales_num = result[0] if result[0] is not None else 0
    orders_num = result[1] if result[1] is not None else 0

    conn.close()

    log('get_sales:', sku, start_date, end_date, sales_num, orders_num)
    return sales_num, orders_num  # 返回销售量和订单量的元组

def get_last_week_sales(sku):
    today = datetime.today().date()
    # last_week_start = today - timedelta(days=today.weekday() + 14)
    last_week_start = (datetime.now() - timedelta(days=14)).strftime("%Y-%m-%d")
    last_week_end = (datetime.now() - timedelta(days=8)).strftime("%Y-%m-%d")
    # log('远7天',last_week_start,last_week_end,sku)
    return get_sales(sku, str(last_week_start), str(last_week_end))

def get_near_week_sales(sku):
    today = datetime.today().date()
    # last_week_start = today - timedelta(days=today.weekday() + 14)
    last_week_start = (datetime.now() - timedelta(days=7)).strftime("%Y-%m-%d")
    last_week_end = (datetime.now() - timedelta(days=1)).strftime("%Y-%m-%d")
    # log('远7天',last_week_start,last_week_end,sku)
    return get_sales(sku, str(last_week_start), str(last_week_end))

def get_last_month_sales(sku):
    today = datetime.today().date()
    # first_day_of_this_month = today.replace(day=1)
    # last_month_end = first_day_of_this_month - timedelta(days=1)
    # last_month_start = last_month_end.replace(day=1)
    last_month_start = (datetime.now() - timedelta(days=60)).strftime("%Y-%m-%d")
    last_month_end = (datetime.now() - timedelta(days=31)).strftime("%Y-%m-%d")
    # log('远30天',last_month_start,last_month_end,sku)
    return get_sales(sku, str(last_month_start), str(last_month_end))

def get_near_month_sales(sku):
    today = datetime.today().date()
    # first_day_of_this_month = today.replace(day=1)
    # last_month_end = first_day_of_this_month - timedelta(days=1)
    # last_month_start = last_month_end.replace(day=1)
    last_month_start = (datetime.now() - timedelta(days=30)).strftime("%Y-%m-%d")
    last_month_end = (datetime.now() - timedelta(days=1)).strftime("%Y-%m-%d")
    # log('远30天',last_month_start,last_month_end,sku)
    return get_sales(sku, str(last_month_start), str(last_month_end))

def exists_sales_1_days_ago(skc):
    conn = sqlite3.connect(db_file)  # 替换成你的数据库文件
    cursor = conn.cursor()
    date_threshold = (datetime.today().date() - timedelta(days=1)).isoformat()
    # 使用 str.format() 格式化 SQL
    sql = '''
        SELECT 1 FROM sales WHERE skc = '{skc}' AND date = '{date}' LIMIT 1
    '''.format(skc=skc, date=date_threshold)
    log("exists_sales_1_days_ago:", sql.strip())  # 打印 SQL 语句
    cursor.execute('''
        SELECT 1 FROM sales WHERE skc = ? AND date <= ? LIMIT 1
    ''', (skc, date_threshold))
    result = cursor.fetchone()
    conn.close()
    return result is not None

def create_indexes():
    conn = sqlite3.connect(db_file)
    cursor = conn.cursor()
    # 创建 spu + date 联合索引
    cursor.execute('''
        CREATE INDEX IF NOT EXISTS idx_sales_skc_date ON sales (skc, date);
    ''')
    # 创建 sku + date 唯一索引
    cursor.execute('''
        CREATE UNIQUE INDEX IF NOT EXISTS idx_sales_sku_date_unique ON sales (sku, date);
    ''')
    conn.commit()  # 提交更改
    conn.close()  # 关闭连接
    log("索引创建成功！")

init_db()

if __name__ == '__main__':
    main(sys.argv)


# pip install lark-oapi -U
import json
import os
import uuid
from typing import Optional

import lark_oapi as lark
from lark_oapi.api.im.v1 import *


class FeishuBot:
    """飞书机器人类，封装所有机器人相关功能"""
    
    def __init__(self, config):
        """
        初始化飞书机器人
        
        Args:
            config: 配置对象，包含应用ID、应用密钥和群组信息
        """
        self.config = config
        self._client = None
    
    @property
    def client(self):
        """获取飞书客户端，使用懒加载模式"""
        if self._client is None:
            self._client = lark.Client.builder() \
                .app_id(self.config.feishu_bot.app_id) \
                .app_secret(self.config.feishu_bot.app_secret) \
                .log_level(lark.LogLevel.INFO) \
                .build()
        return self._client
    
    def _get_chat_id(self, bot_name: str) -> Optional[str]:
        """
        根据群组别名获取群组ID
        
        Args:
            bot_name: 群组别名
            
        Returns:
            群组ID，如果别名不存在则返回None
        """
        return self.config.dict_feishu_group.get(bot_name)
    
    def _handle_response_error(self, response, operation_name: str):
        """
        处理API响应错误
        
        Args:
            response: API响应对象
            operation_name: 操作名称，用于错误日志
        """
        if not response.success():
            lark.logger.error(
                f"{operation_name} failed, code: {response.code}, "
                f"msg: {response.msg}, log_id: {response.get_log_id()}, "
                f"resp: \n{json.dumps(json.loads(response.raw.content), indent=4, ensure_ascii=False)}"
            )
            return True
        return False
    
    def send_text(self, content: str, bot_name: str = 'test') -> bool:
        """
        发送文本消息
        
        Args:
            content: 文本内容
            bot_name: 群组别名，默认为'test'
            
        Returns:
            发送是否成功
        """
        chat_id = self._get_chat_id(bot_name)
        if not chat_id:
            lark.logger.error(f"未找到群组别名 '{bot_name}' 对应的群组ID")
            return False
        
        message_content = {"text": content}
        
        # 构造请求对象
        request: CreateMessageRequest = CreateMessageRequest.builder() \
            .receive_id_type("chat_id") \
            .request_body(CreateMessageRequestBody.builder()
                          .receive_id(chat_id)
                          .msg_type("text")
                          .content(json.dumps(message_content))
                          .uuid(str(uuid.uuid4()))
                          .build()) \
            .build()
        
        # 发起请求
        response: CreateMessageResponse = self.client.im.v1.message.create(request)
        
        # 处理失败返回
        if self._handle_response_error(response, "send_text"):
            return False
        
        # 处理业务结果
        lark.logger.info(lark.JSON.marshal(response.data, indent=4))
        return True
    
    def send_image(self, file_path: str, bot_name: str = 'test') -> bool:
        """
        发送图片消息
        
        Args:
            file_path: 图片文件路径
            bot_name: 群组别名，默认为'test'
            
        Returns:
            发送是否成功
        """
        # 先上传图片获取image_key
        image_key = self.upload_image(file_path)
        if not image_key:
            return False
        
        chat_id = self._get_chat_id(bot_name)
        if not chat_id:
            lark.logger.error(f"未找到群组别名 '{bot_name}' 对应的群组ID")
            return False
        
        message_content = {"image_key": image_key}
        
        # 构造请求对象
        request: CreateMessageRequest = CreateMessageRequest.builder() \
            .receive_id_type("chat_id") \
            .request_body(CreateMessageRequestBody.builder()
                          .receive_id(chat_id)
                          .msg_type("image")
                          .content(json.dumps(message_content))
                          .uuid(str(uuid.uuid4()))
                          .build()) \
            .build()
        
        # 发起请求
        response: CreateMessageResponse = self.client.im.v1.message.create(request)
        
        # 处理失败返回
        if self._handle_response_error(response, "send_image"):
            return False
        
        # 处理业务结果
        lark.logger.info(lark.JSON.marshal(response.data, indent=4))
        return True
    
    def send_excel(self, file_path: str, bot_name: str = 'test') -> bool:
        """
        发送Excel文件
        
        Args:
            file_path: Excel文件路径
            bot_name: 群组别名，默认为'test'
            
        Returns:
            发送是否成功
        """
        # 先上传文件获取file_key
        file_key = self.upload_excel(file_path)
        if not file_key:
            return False
        
        chat_id = self._get_chat_id(bot_name)
        if not chat_id:
            lark.logger.error(f"未找到群组别名 '{bot_name}' 对应的群组ID")
            return False
        
        message_content = {"file_key": file_key}
        
        # 构造请求对象
        request: CreateMessageRequest = CreateMessageRequest.builder() \
            .receive_id_type("chat_id") \
            .request_body(CreateMessageRequestBody.builder()
                          .receive_id(chat_id)
                          .msg_type("file")
                          .content(json.dumps(message_content))
                          .uuid(str(uuid.uuid4()))
                          .build()) \
            .build()
        
        # 发起请求
        response: CreateMessageResponse = self.client.im.v1.message.create(request)
        
        # 处理失败返回
        if self._handle_response_error(response, "send_excel"):
            return False
        
        # 处理业务结果
        lark.logger.info(lark.JSON.marshal(response.data, indent=4))
        return True
    
    def upload_excel(self, file_path: str) -> Optional[str]:
        """
        上传Excel文件
        
        Args:
            file_path: 文件路径
            
        Returns:
            文件key，上传失败返回None
        """
        if not os.path.exists(file_path):
            lark.logger.error(f"文件不存在: {file_path}")
            return None
        
        try:
            with open(file_path, "rb") as file:
                file_name = os.path.basename(file_path)
                request: CreateFileRequest = CreateFileRequest.builder() \
                    .request_body(CreateFileRequestBody.builder()
                                  .file_type("xls")
                                  .file_name(file_name)
                                  .file(file)
                                  .build()) \
                    .build()
                
                # 发起请求
                response: CreateFileResponse = self.client.im.v1.file.create(request)
                
                # 处理失败返回
                if self._handle_response_error(response, "upload_excel"):
                    return None
                
                # 处理业务结果
                lark.logger.info(lark.JSON.marshal(response.data, indent=4))
                return response.data.file_key
        except Exception as e:
            lark.logger.error(f"上传Excel文件时发生错误: {e}")
            return None
    
    def upload_image(self, file_path: str) -> Optional[str]:
        """
        上传图片文件
        
        Args:
            file_path: 图片文件路径
            
        Returns:
            图片key，上传失败返回None
        """
        if not os.path.exists(file_path):
            lark.logger.error(f"文件不存在: {file_path}")
            return None
        
        try:
            with open(file_path, "rb") as file:
                request: CreateImageRequest = CreateImageRequest.builder() \
                    .request_body(CreateImageRequestBody.builder()
                                  .image_type("message")
                                  .image(file)
                                  .build()) \
                    .build()
                
                # 发起请求
                response: CreateImageResponse = self.client.im.v1.image.create(request)
                
                # 处理失败返回
                if self._handle_response_error(response, "upload_image"):
                    return None
                
                # 处理业务结果
                lark.logger.info(lark.JSON.marshal(response.data, indent=4))
                return response.data.image_key
        except Exception as e:
            lark.logger.error(f"上传图片文件时发生错误: {e}")
            return None